@@ -81,7 +81,7 @@ bool Bayonne::loadPlugin(const char *prefix, const char *path)
 
 #ifdef	WIN32
 	if(!prefix)
-		"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins"
+		"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins";
 #else
 	if(!prefix)
 		prefix = LIBDIR_FILES;
