@@ -53,6 +53,7 @@
 #define	NO_TIMESLOT	0xffff
 #define	MAX_DTMF	32
 #define	MAX_LIST	256
+#define	MAX_LIBINPUT	256
 
 namespace ost {
 
@@ -403,6 +404,13 @@ public:
 
 	} event_t;
 
+	typedef	struct
+	{
+		Line line;
+		char text[MAX_LIBINPUT];
+		const char *list[MAX_LIBINPUT / 2];
+	}	libaudio_t;
+
 	/**
 	 * The event data structure includes the event identifier and
 	 * any paramaters.  Additional information is attached both to
@@ -518,11 +526,10 @@ public:
 		Name *menu;
 		unsigned stack;
 		Line *lib;
+		int pfd;
 		int result;
 		int pid;
-#ifndef	WIN32
-		int pfd;
-#endif
+		libaudio_t *libaudio;
 
 		union
 		{
@@ -1684,6 +1691,16 @@ protected:
 	 */
 	void setRunning(void);
 
+	/**
+	 * Set the result of a libexec initiated process and change
+	 * state to libexec.  Return false if no libexec support, or
+	 * if not currently libexecing...
+	 *
+	 * @return true if in libexec
+	 * @param result code to set.
+	 */
+	bool setLibexec(int result);
+
 	/**
 	 * ccengine.
 	 */
