@@ -31,8 +31,10 @@ ScriptInterp(), audio()
 	logevents = logtrace = NULL;
 	state.logstate = (Handler)NULL;
 	state.pid = 0;
-#ifndef	WIN32
+#ifdef	HAVE_LIBEXEC
 	state.pfd = -1;
+	state.libaudio = new libaudio_t;
+	state.libaudio->line.args = state.libaudio->list;
 #endif
 	span = s;
 	timeslot = ts;
@@ -167,15 +169,15 @@ timeout_t BayonneSession::getJoinTimer(void)
 
 uint32 BayonneSession::newTid(void)
 {
+#ifdef	HAVE_LIBEXEC
 	if(state.pid)
 	{
 		Process::cancel(state.pid);
-#ifndef	WIN32
 		if(state.pfd > -1)
 			::close(state.pfd);
 		state.pfd = -1;
-#endif	
 	}
+#endif
 
 	state.pid = 0;
 	snprintf(var_tid, sizeof(var_tid), "%04d+%08lx", timeslot, ++tseq);
@@ -531,6 +533,25 @@ timeout_t BayonneSession::getMSecTimeout(const char *id)
 	return atol(cp);
 }
 
+#ifdef	HAVE_LIBEXEC
+bool BayonneSession::setLibexec(int result)
+{
+	if(!state.pid)
+		return false;
+
+	state.result = result;
+	setState(STATE_LIBEXEC);
+	return true;
+}
+
+#else
+
+bool BayonneSession::setLibexec(int result)
+{
+	return false;
+}
+#endif
+
 void BayonneSession::setRunning(void)
 {
 	setState(STATE_RUNNING);
