@@ -16,6 +16,10 @@
 
 #include "driver.h"
 
+#ifdef	WIN32
+#define	strdup	ost::strdup
+#endif
+
 namespace sipdriver {
 using namespace ost;
 using namespace std;
@@ -297,7 +301,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 
 	reg->active = false;
 	reg->protocol = "sip";
-	reg->interface = getLast("interface");
+	reg->iface = getLast("interface");
 	reg->uri = ScriptChecks::findKeyword(line, "uri");
 	reg->hostid = ScriptChecks::findKeyword(line, "proxy");
 	reg->userid = ScriptChecks::findKeyword(line, "userid");
@@ -357,7 +361,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	buf[len] = 0;
 	pos = len;
 
-	setString(buf + pos, sizeof(buf) - pos, reg->interface);
+	setString(buf + pos, sizeof(buf) - pos, reg->iface);
 	len = strlen(buf) + 1;
 	reg->contact = (const char *)img->getMemory(len);
 	strcpy((char *)reg->contact, buf);
@@ -599,7 +603,7 @@ sip404:
 			if(!s)
 			{
 				slog.warn("sip: no timeslots available");
-sip480:				              
+//sip480:				              
 				endImage(img);                  
 				eXosip_lock();
                                 eXosip_answer_call(sevent->did, 480, NULL);
@@ -609,7 +613,7 @@ sip480:
 			
 			osip_uri_init(&uri);
 			osip_from_init(&from);
-			session = dynamic_cast<Session *>(s);
+			session = (Session *)(s);
 
 			session->cid = sevent->cid;
 			session->did = sevent->did;
@@ -759,8 +763,8 @@ exitcall:
                                 goto killit;
 			}
 			                
-			if(!strcasecmp(sevent->i_ctt->type, "application") &&
-                           !strcasecmp(sevent->i_ctt->subtype, "dtmf-relay") &&
+			if(!stricmp(sevent->i_ctt->type, "application") &&
+                           !stricmp(sevent->i_ctt->subtype, "dtmf-relay") &&
                            !osip_list_eol(sevent->i_bodies, 0)) 
 			{
 				memset(&digit, 0, 10);
