@@ -50,13 +50,13 @@ using namespace std;
 #endif
 
 #ifdef	WIN32
-#define	PROMPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Phrasebook"
-#define	SCRIPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Scripts"
-#define	VAR_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Files"
-#define	LOG_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Logs"
-#define	CONFIG_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Config"
-#define	RUN_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Logs"
-#define	LIBEXEC_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Libexec"
+#define	PROMPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Audio"
+#define	SCRIPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Scripts"
+#define	VAR_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Files"
+#define	LOG_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Logs"
+#define	CONFIG_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Config"
+#define	RUN_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Logs"
+#define	LIBEXEC_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Libxec"
 #define	LIBDIR_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Runtime"
 #define	MODULE_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins"
 #define	DRIVER_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Drivers"
